Installation — asiembedding 00.00.01 documentation

# Installation

## Requirements

- A shared-object library for a supported QM driver (FHI-aims)

- asi4py >= 1.3.0

- ASE <= 2.22.1

## ASI Embedding Installation

### Installation from PyPI

ASI Embedding may be installed from the PyPI respository, which will automatically download the source code, install the required packages, and install ASI Embedding in the target used for pip installation:

    $ pip install --upgrade asiembedding

### Installation from Source

The source code for ASI Embedding may be downloaded from the github repository on a local machine, and pip installation executed in the top directory of the ASI Embedding package:

    $ git clone git@github.com:GabrielBram/ASI_Embedding.git
    $ cd ASI_Embedding
    $ pip install .

## QM Driver Installation

### FHI-aims

Warning

FHI-aims is a software package licensed by MS1P for academic and commercial settings. If you do not hold a FHI-aims license, please refer to the licensing page for further information and instructions.

Download the development version of FHI-aims from the supported Gitlab repository:

    $ git clone git@aims-git.rz-berlin.mpg.de:aims/FHIaims.git

Instructions for compiling FHI-aims may be found in either the FHI-aims manual, with additional architecture/compiler specific instructions at aims-club. No modifications to the installation of FHI-aims are required except for a CMake directive to install a shared object library as opposed to a standard executible (which is a requirement of ASI in general). This is achieved by adding the following line to the initial_cmake.cache file:

    set(BUILD_SHARED_LIBS ON CACHE BOOL "" FORCE)